import Vue from "vue";
import Router from "vue-router";

Vue.use(Router);

/* Layout */
import Layout from "@/layout";

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: "/login",
    component: () => import("@/views/login/index"),
  },
  {
    path: "/",
    component: Layout,
    // redirect: "/index",
    children: [
      {
        path: "index",
        name: "index",
        component: () => import("@/views/dashboard/index"),
        meta: { title: "账号列表", icon: "el-icon-s-cooperation", role: [0] },
      },
    ],
  },
  {
    path: "/userList",
    component: Layout,
    children: [
      {
        path: "index",
        name: "userList",
        component: () => import("@/views/userList/index"),
        meta: {
          title: "授权账号列表",
          role: [0, 1],
          icon: "el-icon-s-finance",
        },
      },
    ],
  },
  {
    path: "/pointManagement",
    redirect: "/pointManagement/index",
    component: Layout,
    children: [
      {
        path: "index",
        name: "pointManagement",
        component: () => import("@/views/pointManagement/index"),
        meta: {
          title: "巡逻点位管理",
          role: [0, 1],
          icon: "el-icon-place",
        },
      },
    ],
  },

  {
    path: "/personnelManagement",
    component: Layout,
    children: [
      {
        path: "index",
        name: "personnelManagement",
        component: () => import("@/views/personnelManagement/index"),
        meta: {
          title: "人员账号管理",
          role: [0, 1],
          icon: "el-icon-user-solid",
        },
      },
    ],
  },
  {
    path: "/ruleManagement",
    component: Layout,
    children: [
      {
        path: "index",
        name: "ruleManagement",
        component: () => import("@/views/ruleManagement/index"),
        meta: { title: "巡逻规则管理", role: [1], icon: "el-icon-s-order" },
      },
    ],
  },
  {
    path: "/recordList",
    component: Layout,
    children: [
      {
        path: "index",
        name: "recordList",
        component: () => import("@/views/recordList/index"),
        meta: { title: "巡逻记录列表", role: [0, 1, 2], icon: "el-icon-help" },
      },
    ],
  },
  {
    path: "/recordCrashList",
    component: Layout,
    children: [
      {
        path: "index",
        name: "recordCrashList",
        component: () => import("@/views/recordCrashList/index"),
        meta: {
          title: "异常记录列表",
          role: [0, 1, 2],
          icon: "el-icon-warning",
        },
      },
    ],
  },

  {
    path: "/404",
    component: () => import("@/views/404"),
    hidden: true,
  },
  // 404 page must be placed at the end !!!
  { path: "*", redirect: "/404", hidden: true },
];

const createRouter = () =>
  new Router({
    // mode: 'history', // require service support
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRoutes,
  });

const router = createRouter();

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter();
  router.matcher = newRouter.matcher; // reset router
}

export default router;
